'use strict';

/**
 * Module dependencies.
 */


var url       = require('url'),
    Promise   = require('bluebird'),
    request   = require('request'),
    joi       = require('joi'),
    Mail      = require('./schema/mail'),
    internals = {};

internals.PING_SERVICE = '/ping';
internals.PING_SERVICE_METHOD = 'POST';

internals.SEND_MAIL_SERVICE = '/api/v1/notification/email';
internals.SEND_MAIL_SERVICE_METHOD = 'POST';


function NotificationClient(baseUrl) {
  this.baseUrl = baseUrl;
  this.pingUrl = url.resolve(this.baseUrl, internals.PING_SERVICE);
  this.sendMailUrl = url.resolve(this.baseUrl, internals.SEND_MAIL_SERVICE);
}


NotificationClient.prototype.ping = function () {
  var url = this.pingUrl;
  return new Promise(function (resolve, reject) {
    // Send request to server
    request({
      url: url,
      method: 'POST'
    }, function (error, response) {
      if (error) {
        reject(error);
      }
      else {
        resolve(response);
      }
    });
  });
};


NotificationClient.prototype.sendMail = function (mail) {
  var url = this.sendMailUrl;
  return new Promise(function (resolve, reject) {
    Joi.validate(mail, Mail, function (err, safeMail) {
      if (err) {
        reject(err);
      }
      request({
        url: url,
        method: internals.SEND_MAIL_SERVICE_METHOD,
        body: safeMail
      }, function (error, response) {
        if (error) {
          reject(error);
        }
        else {
          resolve(response);
        }
      });
    });
  });
};


